package meerkat.voting.controller.callbacks;


import meerkat.voting.controller.commands.*;
import meerkat.voting.controller.commands.ControllerCommand;
import meerkat.voting.controller.commands.RestartVotingCommand;
import meerkat.voting.ui.VotingBoothUI.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.concurrent.LinkedBlockingQueue;

public class CastOrAuditCallback extends ControllerCallback {
    protected final static Logger logger = LoggerFactory.getLogger(CastOrAuditCallback.class);

    public CastOrAuditCallback(int requestId,
                               long ballotSerialNumber,
                               LinkedBlockingQueue<ControllerCommand> controllerQueue) {
        super(requestId, ballotSerialNumber, controllerQueue);
    }

    @Override
    public void onSuccess(Object result) {
        assert (result instanceof FinalizeBallotChoice);

        if (result == FinalizeBallotChoice.CAST) {
            controllerQueue.add(new CastCommand(getRequestIdentifier(), getBallotSerialNumber()));
        }
        else if (result == FinalizeBallotChoice.AUDIT) {
            controllerQueue.add(new AuditCommand(getRequestIdentifier(), getBallotSerialNumber()));
        }
        else {
            logger.error("CastOrAuditCallback got an unrecognized response: " + result);
            controllerQueue.add(new RestartVotingCommand(getRequestIdentifier(), getBallotSerialNumber()));
        }

    }

    @Override
    public void onFailure(Throwable t) {
        logger.error("CastOrAuditCallback got a failure: " + t);
        controllerQueue.add(new RestartVotingCommand(getRequestIdentifier(), getBallotSerialNumber()));
    }
}



