package meerkat.voting.controller.callbacks;

import meerkat.protobuf.Voting;
import meerkat.voting.controller.commands.ChannelDeterminedCommand;
import meerkat.voting.controller.commands.ControllerCommand;
import meerkat.voting.controller.commands.RestartVotingCommand;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.concurrent.LinkedBlockingQueue;

/**
 * Created by hai on 11/04/16.
 */
public class ChannelChoiceCallback extends ControllerCallback {
    protected final static Logger logger = LoggerFactory.getLogger(ChannelChoiceCallback.class);

    public ChannelChoiceCallback(int requestId,
                                 long ballotSerialNumber,
                                 LinkedBlockingQueue<ControllerCommand> controllerQueue) {
        super(requestId, ballotSerialNumber, controllerQueue);
    }

    @Override
    public void onSuccess(Object result) {
        assert (result instanceof Voting.BallotAnswer[]);
        if (((Voting.BallotAnswer[])result).length != 0) {
            logger.debug("callback for channel choice returned success");
            controllerQueue.add(
                    new ChannelDeterminedCommand(getRequestIdentifier(), getBallotSerialNumber(), (Voting.BallotAnswer[]) result));
        }
        else {
            logger.debug("ChannelChoiceCallback got a cancellation response: " + result);
            controllerQueue.add(new RestartVotingCommand(getRequestIdentifier(), getBallotSerialNumber()));
        }
    }

    @Override
    public void onFailure(Throwable t) {
        logger.error("channel choice initiated a failure: " + t);
        controllerQueue.add(new RestartVotingCommand(getRequestIdentifier(), getBallotSerialNumber()));
    }
}
