package meerkat.voting.controller.callbacks;

import meerkat.protobuf.Voting;
import meerkat.voting.controller.commands.ControllerCommand;
import meerkat.voting.controller.commands.EncryptAndCommitBallotCommand;
import meerkat.voting.controller.commands.RestartVotingCommand;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.concurrent.LinkedBlockingQueue;

public class VotingCallback extends ControllerCallback {
    protected final static Logger logger = LoggerFactory.getLogger(VotingCallback.class);

    public VotingCallback(int requestId,
                          long ballotSerialNumber,
                          LinkedBlockingQueue<ControllerCommand> controllerQueue) {
        super(requestId, ballotSerialNumber, controllerQueue);
    }

    @Override
    public void onSuccess(Object result) {
        assert result instanceof Voting.BallotAnswer[];
        if (((Voting.BallotAnswer[])result).length != 0) {
            logger.debug("callback for voting returned success");
            controllerQueue.add(
                    new EncryptAndCommitBallotCommand(getRequestIdentifier(), getBallotSerialNumber(), (Voting.BallotAnswer[]) result));
        }
        else {
            logger.debug("VotingCallback got a cancellation response: " + result);
            controllerQueue.add(new RestartVotingCommand(getRequestIdentifier(), getBallotSerialNumber()));
        }
    }

    @Override
    public void onFailure(Throwable t) {
        logger.error("voting initiated a failure: " + t);
        controllerQueue.add(new RestartVotingCommand(getRequestIdentifier(), getBallotSerialNumber()));
    }
}
