package meerkat.voting.encryptor;

import meerkat.protobuf.Voting.*;

/**
 * An interface for the encryptor component of the voting booth
 */
public interface VotingBoothEncryptor {

    /**
     * A simple class for pairing EncrypedBallot together with its matching BallotSecrets
     */
    public class EncryptionAndSecrets {
        private final EncryptedBallot encryptedBallot;
        private final BallotSecrets secrets;

        public EncryptionAndSecrets (EncryptedBallot encryptedBallot, BallotSecrets secrets) {
            this.encryptedBallot = encryptedBallot;
            this.secrets = secrets;
        }

        public EncryptedBallot getEncryptedBallot ()  {
            return encryptedBallot;
        }

        public BallotSecrets getSecrets()  {
            return secrets;
        }
    }


    /**
     * This function encrypts the plaintext ballot using the booth's keys
     * @param plaintextBallot - all plaintext ballot info of the voter
     * @return an encryption of the ballot
     */
    public EncryptionAndSecrets encrypt (PlaintextBallot plaintextBallot);


    //TODO: probably needs some key generation methods as well
}
